
"""A Python package for visually auditing machine learning models for fairness through the use of interpretable visualizations summarizing intersectional bias."""

__author__ = """David Munechika"""
__email__ = 'david.munechika@gatech.edu'
__version__ = '0.1.3'

from visual_auditor.visual_auditor import *